@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: client.c,v 1.55 2006/04/26 10:33:41 evertonm Exp $ */
+/* $Id: client.c,v 1.56 2006/05/12 19:06:47 evertonm Exp $ */
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -778,7 +778,10 @@ static void tcp_pipe_stop(int sd)
   nepim_sock_show_opt(stderr, sd);
 }
 
-static void spawn_one_tcp_client(const char *hostname, const char *portname)
+static void spawn_one_tcp_client(const struct sockaddr *bindaddr,
+				 int bindaddr_len,
+				 const char *hostname,
+				 const char *portname)
 {
   struct addrinfo hints;
   struct addrinfo *ai_res;
@@ -854,17 +857,21 @@ static void spawn_one_tcp_client(const char *hostname, const char *portname)
   }
 
   for (ai = ai_res; ai; ai = ai->ai_next) {
+    char addr_str[500];
     int nodelay;
     int sd;
 
+    nepim_sock_dump_addr(addr_str, sizeof addr_str,
+			 ai->ai_addr, ai->ai_addrlen);
+
     if (ai->ai_family == PF_UNIX)
       fprintf(stderr, 
 	      "UNIX stream socket trying path=%s\n",
 	      hostname);
     else
       fprintf(stderr, 
-	      "TCP socket trying %s,%s\n",
-	      hostname, portname);
+	      "TCP socket trying %s,%d\n",
+	      addr_str, nepim_sock_get_port(ai->ai_addr));
 
     if (nepim_global.no_inet6 && (ai->ai_family == PF_INET6))
       continue;
@@ -874,7 +881,8 @@ static void spawn_one_tcp_client(const char *hostname, const char *portname)
 
     nodelay = (nepim_global.nagle == -1) ? -1 : !nepim_global.nagle;
 
-    sd = nepim_connect_client_socket(ai->ai_addr, ai->ai_addrlen,
+    sd = nepim_connect_client_socket(bindaddr, bindaddr_len,
+				     ai->ai_addr, ai->ai_addrlen,
                                      ai->ai_family, ai->ai_socktype, 
                                      ai->ai_protocol,
                                      nepim_global.pmtu_mode,
@@ -891,23 +899,20 @@ static void spawn_one_tcp_client(const char *hostname, const char *portname)
 		hostname, sd);
       else
 	fprintf(stderr, 
-		"could not connect TCP socket to %s,%s: %d\n",
-		hostname, portname, sd);
+		"could not connect TCP socket to %s,%d: %d\n",
+		addr_str, nepim_sock_get_port(ai->ai_addr), sd);
 
       continue;
     }
 
     if (ai->ai_family == AF_UNIX)
       fprintf(stderr, 
-	      "%d: UNIX stream socket connected to: path=%s\n",
+	      "%d: UNIX stream socket connected to path=%s\n",
 	      sd, hostname); 
     else
       fprintf(stderr, 
-	      "%d: TCP socket connected to: "
-	      "host=%s,%s len=%d family=%d type=%d proto=%d\n",
-	      sd, hostname, portname, 
-	      ai->ai_addrlen, ai->ai_family, 
-	      ai->ai_socktype, ai->ai_protocol);
+	      "%d: TCP socket connected to %s,%d\n",
+	      sd, addr_str, nepim_sock_get_port(ai->ai_addr));
     
     {
       nepim_greet_t opt;
@@ -942,6 +947,21 @@ static void parse_hosts(const char *host_list)
 {
   int size = addr_list_size(host_list);
   int i, j;
+  union {
+    struct sockaddr_in inet;
+    struct sockaddr_in6 inet6;
+  } bind_buf;
+  int bind_addr_len = sizeof bind_buf;
+  struct sockaddr *bind_addr = 0;
+
+  if (nepim_global.bind_list) {
+    bind_addr = nepim_addrlist_findfirst(SOCK_STREAM, IPPROTO_TCP,
+					 nepim_global.bind_list,
+					 (struct sockaddr *) &bind_buf,
+					 &bind_addr_len);
+    if (!bind_addr)
+      return;
+  }
 
   /* scan host_list */
   for (j = 0; j < size; ++j) {
@@ -962,7 +982,8 @@ static void parse_hosts(const char *host_list)
 
     /* create sockets */
     for (i = 0; i < nepim_global.pipes; ++i)
-      spawn_one_tcp_client(hostname, portname);
+      spawn_one_tcp_client(bind_addr, bind_addr_len,
+			   hostname, portname);
 
   } /* scan host_list */
 }
