@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: common.c,v 1.62 2006/05/19 14:19:29 evertonm Exp $ */
+/* $Id: common.c,v 1.64 2006/05/23 20:38:41 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -38,31 +38,42 @@ MA 02110-1301 USA
 #include "str.h"
 
 
-const char * const NEPIM_LABEL_PARTIAL      = "part";
+const char * const NEPIM_LABEL_PARTIAL      = "prt";
 const char * const NEPIM_LABEL_TOTAL        = "avg";
 const char * const NEPIM_LABEL_TOTAL_BROKEN = "avg(broken)";
 
+static int line = 0;
+
 
 const char *nepim_version()
 {
-  return "0.26";
+  return "0.27";
 }
 
-static void nepim_dump_stat(FILE *out, struct timeval now, const char *label,
+static void header(FILE *out, int ident, int udp)
+{
+  if (!(line++ % 10)) {
+    while (--ident >= 0)
+      putc(' ', out);
+    fprintf(out, " %10s %10s %8s %8s", 
+	    "kbps_in", "kbps_out", "rcv/s", "snd/s");
+    if (udp)
+      fprintf(out, "  %5s  %5s", "loss", "ooo");
+    fprintf(out, "\n");
+  }
+}
+
+static void nepim_dump_stat(FILE *out,
                             long long bytes_recv, long long bytes_sent, 
-                            float interval, long sec_start, 
-                            long sec_duration, int reads, int writes)
+                            float interval, int reads, int writes)
 {
   float kbps_recv = bytes_recv / (interval * 125); /* 8/1000 = 1/125 */
   float kbps_sent = bytes_sent / (interval * 125); /* 8/1000 = 1/125 */
   float read_rate = reads / interval;
   float write_rate = writes / interval;
-  
+
   fprintf(out,
-          ": %s %ld/%ld kbps_in=%.2f kbps_out=%.2f rcv/s=%.2f snd/s=%.2f", 
-          label,
-          now.tv_sec - sec_start,
-          sec_duration,
+          " %10.2f %10.2f %8.2f %8.2f", 
           kbps_recv,
           kbps_sent,
           read_rate,
@@ -75,11 +86,18 @@ void nepim_pipe_stat(FILE *out, struct timeval now,
                      float interval, long sec_start, 
                      long sec_duration, int reads, int writes)
 {
-  fprintf(out, "%d", sd);
+  char buf[100];
+  int pr;
 
-  nepim_dump_stat(out, now, label, bytes_recv, bytes_sent, 
-                  interval, sec_start, sec_duration,
-                  reads, writes);
+  pr = snprintf(buf, sizeof buf, "%3d %4s %5ld",
+		sd, label, sec_duration - (now.tv_sec - sec_start));
+
+  header(out, pr, 0 /* udp=false */);
+
+  fprintf(out, buf);
+
+  nepim_dump_stat(out, bytes_recv, bytes_sent, 
+                  interval, reads, writes);
 
   fprintf(out, "\n");
 
@@ -95,24 +113,37 @@ void nepim_slot_stat(FILE *out, struct timeval now,
                      long sec_duration, int reads, int writes,
                      uint64_t pkt_expected, uint64_t pkt_lost, uint64_t pkt_ooo)
 {
-  fprintf(out, "%d %d-%d",
-	  sd, local_slot, remote_slot);
+  char buf[100];
+  int pr;
 
-  nepim_dump_stat(out, now, label, bytes_recv, bytes_sent, 
-                  interval, sec_start, sec_duration,
-                  reads, writes);
+  pr = snprintf(buf, sizeof buf, 
+		"%3d %3d %3d %4s %5ld",
+		sd, local_slot, remote_slot,
+		label, sec_duration - (now.tv_sec - sec_start));
+
+  header(out, pr, 1 /* udp=true */);
+
+  fprintf(out, buf);
+
+  nepim_dump_stat(out, bytes_recv, bytes_sent, 
+                  interval, reads, writes);
 
   {
-    float loss_ratio = 100 * pkt_lost;
-    float ooo_ratio = 100 * pkt_ooo;
+    float loss_ratio = pkt_lost;
+    float ooo_ratio  = pkt_ooo;
+
+#if 0
+    loss_ratio *= 100;
+    ooo_ratio  *= 100;
+#endif
     
     loss_ratio /= pkt_expected;
-    ooo_ratio /= pkt_expected;
+    ooo_ratio  /= pkt_expected;
     
     fprintf(out,
-            " loss=%llu/%.2f%% ooo=%llu/%.2f%%",
-            pkt_lost, loss_ratio,
-	    pkt_ooo, ooo_ratio);
+            " %5.4f %5.4f",
+            loss_ratio,
+	    ooo_ratio);
   }
 
   fprintf(out, "\n");
