@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: greet.c,v 1.14 2006/04/18 22:56:33 evertonm Exp $ */
+/* $Id: greet.c,v 1.15 2006/04/23 06:33:46 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -44,6 +44,7 @@ const char *GREET_FILL_BYTE         = "fill_byte=";
 const char *GREET_PAUSE_DURATION    = "pause_duration=";
 const char *GREET_SOCKET_KEEPALIVE  = "sock_ka=";
 const char *GREET_NAGLE             = "nagle=";
+const char *GREET_OVERHEAD          = "overhead=";
 const char *GREET_PASSWORD          = "password=";
 
 #define NEPIM_GREET_PARSE_OK     (0)
@@ -70,7 +71,7 @@ int nepim_write_greetings(const nepim_greet_t *opt, char *buf, int buf_size)
                 " %s%d %s%d %s%d"
                 " %s%ld %s%d %s%d"
 		" %s0x%08x %s%d %s%d %s0x%02x %s%d"
-		" %s%d %s%d %s%s\n", 
+		" %s%d %s%d %s%d %s%s\n", 
                 GREET_SERVER_SEND,       opt->must_send,
                 GREET_BIT_RATE,          opt->bit_rate,
                 GREET_PKT_RATE,          opt->pkt_rate,
@@ -86,6 +87,7 @@ int nepim_write_greetings(const nepim_greet_t *opt, char *buf, int buf_size)
                 GREET_PAUSE_DURATION,    opt->pause_duration,
                 GREET_SOCKET_KEEPALIVE,  opt->socket_keepalive,
                 GREET_NAGLE,             opt->nagle,
+		GREET_OVERHEAD,          opt->overhead,
                 GREET_PASSWORD,          opt->password_buf);
 
   if (pr < 1)
@@ -122,6 +124,7 @@ int nepim_parse_greetings(nepim_greet_t *opt,
   const int GREET_PAUSE_DURATION_LEN    = strlen(GREET_PAUSE_DURATION);
   const int GREET_SOCKET_KEEPALIVE_LEN  = strlen(GREET_SOCKET_KEEPALIVE);
   const int GREET_NAGLE_LEN             = strlen(GREET_NAGLE);
+  const int GREET_OVERHEAD_LEN          = strlen(GREET_OVERHEAD);
   const int GREET_PASSWORD_LEN          = strlen(GREET_PASSWORD);
 
   int       server_send       = -2;
@@ -139,6 +142,7 @@ int nepim_parse_greetings(nepim_greet_t *opt,
   int       pause_duration    = -2;
   int       socket_keepalive  = -2;
   int       nagle             = -2;
+  int       overhead          = -2;
 
   assert(opt->password_buf);
   assert(opt->password_buf_size > 0);
@@ -243,6 +247,11 @@ int nepim_parse_greetings(nepim_greet_t *opt,
       continue;
     }
 
+    if (!strncmp(tok, GREET_OVERHEAD, GREET_OVERHEAD_LEN)) {
+      overhead = atoi(tok + GREET_OVERHEAD_LEN);
+      continue;
+    }
+
     if (!strncmp(tok, GREET_PASSWORD, GREET_PASSWORD_LEN)) {
       const char *tmp_past_end = tmp + sizeof(tmp);
       const char *pass;
@@ -300,6 +309,7 @@ int nepim_parse_greetings(nepim_greet_t *opt,
   opt->pause_duration      = pause_duration;
   opt->socket_keepalive    = socket_keepalive;
   opt->nagle               = nagle;
+  opt->overhead            = overhead;
 
   return NEPIM_GREET_PARSE_OK;
 }
