@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: int.h,v 1.3 2005/11/04 09:56:14 evertonm Exp $ */
+/* $Id: int.h,v 1.5 2006/05/10 23:23:19 evertonm Exp $ */
 
 
 #ifndef NEPIM_INT_H
@@ -45,13 +45,20 @@ typedef unsigned short int      uint16_t;
 typedef unsigned int            uint32_t;
 #endif
 
+#ifndef __uint64_t_defined
+#define __uint64_t_defined
+typedef unsigned long long      uint64_t;
+#endif
+
 #endif /* HAVE_STDINT */
 
 void nepim_int_sanity();
 
-uint16_t nepim_uint16_read(const char *buf);
-uint32_t nepim_uint32_read(const char *buf);
+uint16_t nepim_uint16_read(const char * const buf);
+uint32_t nepim_uint32_read(const char * const buf);
+uint64_t nepim_uint64_read(const char * const buf);
 void nepim_uint16_write(char *buf, uint16_t value);
 void nepim_uint32_write(char *buf, uint32_t value);
+void nepim_uint64_write(char *buf, uint64_t value);
 
 #endif /* NEPIM_INT_H */
