@@ -21,7 +21,7 @@ MA 02110-1301 USA
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.54 2006/05/19 14:19:29 evertonm Exp $
+  $Id: main.c,v 1.55 2006/05/23 20:38:41 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -102,6 +102,7 @@ static void usage(FILE *out, const char *prog_name)
           "  -6             disable IPv6\n"
           "  -4             disable IPv4\n"
 	  "  -q             quietly hide soft read/write errors\n"
+	  "  -Q             quietly hide debug errors\n"
 	  "  -y tos         ip tos (defaults to %d, tos=-1 means don't change)\n"
 	  "  -K udp-ka-time UDP keepalive timeout (defaults to %ld us)\n"
 	  "\n"
@@ -320,6 +321,11 @@ int main(int argc, const char *argv[])
       continue;
     }
 
+    if (!strcmp(arg, "-Q")) {
+      nepim_global.debug_error_verbose = 0;
+      continue;
+    }
+
     if (!strcmp(arg, "-f")) {
       int j = i + 1;
 
