@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: server.c,v 1.66 2006/04/26 10:33:42 evertonm Exp $ */
+/* $Id: server.c,v 1.67 2006/05/12 19:06:47 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -947,17 +947,10 @@ static int spawn_tcp_listener(const char *hostname, const char *portname)
   }
 
   for (ai = ai_res; ai; ai = ai->ai_next) {
+    char addr_str[500];
     int nodelay;
     int sd;
 
-#if 0
-    fprintf(stderr, 
-            "TCP listener: host=%s,%s(%d) len=%d family=%d type=%d proto=%d\n",
-            hostname, portname, nepim_sock_get_port(ai->ai_addr),
-            ai->ai_addrlen, ai->ai_family, 
-            ai->ai_socktype, ai->ai_protocol);
-#endif
-
     if (nepim_global.no_inet6 && (ai->ai_family == PF_INET6))
       continue;
 
@@ -966,6 +959,9 @@ static int spawn_tcp_listener(const char *hostname, const char *portname)
 
     nodelay = (nepim_global.nagle == -1) ? -1 : !nepim_global.nagle;
 
+    nepim_sock_dump_addr(addr_str, sizeof addr_str,
+			 ai->ai_addr, ai->ai_addrlen);
+
     sd = nepim_create_listener_socket(ai->ai_addr, ai->ai_addrlen,
                                       ai->ai_family, ai->ai_socktype, 
                                       ai->ai_protocol,
@@ -978,9 +974,9 @@ static int spawn_tcp_listener(const char *hostname, const char *portname)
 				      nepim_global.tos);
     if (sd < 0) {
       fprintf(stderr, 
-              "%s: TCP listener socket failed for %s,%s(%d): %d\n",
-              __PRETTY_FUNCTION__, hostname, portname, 
-              nepim_sock_get_port(ai->ai_addr), sd);
+              "%s %s: TCP listener socket failed for %s,%d: %d\n",
+              __FILE__, __PRETTY_FUNCTION__,
+	      addr_str, nepim_sock_get_port(ai->ai_addr), sd);
       break;
     }
 
@@ -991,8 +987,8 @@ static int spawn_tcp_listener(const char *hostname, const char *portname)
     ++tcp_listeners;
 
     fprintf(stderr, 
-            "%d: TCP socket listening on %s,%s(%d)\n",
-            sd, hostname, portname, nepim_sock_get_port(ai->ai_addr));
+	    "%d: TCP socket listening on %s,%d\n",
+	    sd, addr_str, nepim_sock_get_port(ai->ai_addr));
   }
 
   freeaddrinfo(ai_res);
@@ -1189,8 +1185,8 @@ void nepim_server_run()
 {
   int tcp_listeners = 0;
   int udp_listeners = 0;
-  int unix_listeners;
-  int unix_dgram_listeners;
+  int unix_listeners = 0;
+  int unix_dgram_listeners = 0;
 
   /* these must be initialized before spawning listeners */
   nepim_pipe_set_init(&pipes);
@@ -1228,16 +1224,24 @@ void nepim_server_run()
                                         0 /* no join */);
   }
 
-  nepim_global.oop_src->on_signal(nepim_global.oop_src,
-				  SIGINT, on_sigint, 0);
-  nepim_global.oop_src->on_signal(nepim_global.oop_src,
-				  SIGTERM, on_sigterm, 0);
+#if 0
+  fprintf(stderr, "DEBUG ERASEME: %s %s tcp=%d udp=%d stream=%d dgram=%d\n",
+	  __FILE__, __PRETTY_FUNCTION__,
+	  tcp_listeners, udp_listeners,
+	  unix_listeners, unix_dgram_listeners);
+#endif
   
   if (tcp_listeners ||
       udp_listeners ||
       unix_listeners ||
-      unix_dgram_listeners)
+      unix_dgram_listeners) {
+    nepim_global.oop_src->on_signal(nepim_global.oop_src,
+				    SIGINT, on_sigint, 0);
+    nepim_global.oop_src->on_signal(nepim_global.oop_src,
+				    SIGTERM, on_sigterm, 0);
+
     fprintf(stderr, "%s: server ready\n", nepim_global.prog_name);
+  }
 
   for (;;) {
     void *result = oop_sys_run(nepim_global.oop_sys);
