@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: sock.c,v 1.34 2006/04/20 14:49:34 evertonm Exp $ */
+/* $Id: sock.c,v 1.37 2006/05/12 19:14:26 evertonm Exp $ */
 
 #include <assert.h>
 #include <netdb.h>
@@ -90,6 +90,7 @@ struct ipv6_mreq {
 #define NEPIM_SOCK_ERR_WIN_SEND       (-16)
 #define NEPIM_SOCK_ERR_TOS            (-17)
 #define NEPIM_SOCK_ERR_SOCK_KA        (-18)
+#define NEPIM_SOCK_ERR_MSS            (-19)
 
 int nepim_sock_get_port(const struct sockaddr *addr)
 {
@@ -317,7 +318,8 @@ static int create_socket(int domain, int type, int protocol, int pmtu_mode, int
   return sd;
 }
 
-static int socket_mcast_join(int sd, int family, struct sockaddr *addr, int addr_len)
+static int socket_mcast_join(int sd, int family,
+			     const struct sockaddr *addr, int addr_len)
 {
   union {
     struct sockaddr_in inet;
@@ -359,8 +361,7 @@ static int socket_mcast_join(int sd, int family, struct sockaddr *addr, int addr
   return NEPIM_SOCK_ERR_MCAST_JOIN;
 }
 
-int nepim_create_socket(struct sockaddr *addr,
-			int addr_len,
+int nepim_create_socket(const struct sockaddr *addr, int addr_len,
 			int family,
 			int type,
 			int protocol,
@@ -406,6 +407,9 @@ int nepim_create_socket(struct sockaddr *addr,
     return result;
   }
 
+  if (!addr)
+    return sd;
+
   if (bind(sd, addr, addr_len)) {
     char buf[500];
     int e = errno;
@@ -586,8 +590,8 @@ static int nepim_socket_get_keepalive(int sd)
   return keepalive;
 }
 
-int nepim_connect_client_socket(struct sockaddr *addr,
-				int addr_len,
+int nepim_connect_client_socket(const struct sockaddr *bind, int bind_len,
+				struct sockaddr *addr, int addr_len,
 				int family,
 				int type,
 				int protocol,
@@ -602,8 +606,10 @@ int nepim_connect_client_socket(struct sockaddr *addr,
   int sd;
   int result;
 
-  sd = create_socket(family, type, protocol, pmtu_mode, ttl,
-		     win_recv, win_send, nodelay, tos);
+  sd = nepim_create_socket(bind, bind_len,
+			   family, type, protocol, pmtu_mode, ttl,
+			   0 /* mcast_join: false */,
+			   win_recv, win_send, nodelay, tos);
   if (sd < 0)
     return sd;
 
@@ -762,6 +768,27 @@ int nepim_socket_get_tos(int sd)
   return tos;
 }
 
+static int socket_get_mss(int sd)
+{
+  int mss;
+  socklen_t optlen = sizeof(mss);
+
+  if (getsockopt(sd, SOL_TCP, TCP_MAXSEG, &mss, &optlen)) {
+#if 0
+    int e = errno;
+    fprintf(stderr, "%s: %s: get socket TCP_MAXSEG: sd=%d: errno=%d: %s\n",
+	    __FILE__, __PRETTY_FUNCTION__,
+	    sd, e, strerror(e));
+#endif
+
+    return NEPIM_SOCK_ERR_MSS;
+  }
+  
+  assert(optlen == sizeof(mss));
+  
+  return mss;
+}
+
 void nepim_sock_show_opt(FILE *out, int sd)
 {
   int pmtud_mode;
@@ -773,6 +800,7 @@ void nepim_sock_show_opt(FILE *out, int sd)
   int tos;
   int keepalive;
   int nodelay;
+  int mss;
 
   pmtud_mode = nepim_socket_pmtu_get_mode(sd);
   mtu = nepim_socket_pmtu_get_mtu(sd);
@@ -783,15 +811,16 @@ void nepim_sock_show_opt(FILE *out, int sd)
   tos = nepim_socket_get_tos(sd);
   keepalive = nepim_socket_get_keepalive(sd);
   nodelay = nepim_socket_get_nodelay(sd);
+  mss = socket_get_mss(sd);
 
   fprintf(out, 
 	  "%d:"
-	  " pmtud_mode=%d path_mtu=%d tos=%d ttl=%d"
+	  " pmtud_mode=%d path_mtu=%d mss=%d tos=%d ttl=%d"
 	  " mcast_ttl=%d win_recv=%d win_send=%d sock_ka=%d"
 	  " nodelay=%d\n"
 	  ,
 	  sd,
-	  pmtud_mode, mtu, tos, ttl,
+	  pmtud_mode, mtu, mss, tos, ttl,
 	  mcast_ttl, win_recv, win_send, keepalive,
 	  nodelay);
 }
