@@ -38,8 +38,7 @@ int nepim_socket_pmtu_get_mtu(int sd);
 int nepim_socket_get_ttl(int sd);
 int nepim_socket_get_tos(int sd);
 
-int nepim_create_socket(struct sockaddr *addr,
-			int addr_len,
+int nepim_create_socket(const struct sockaddr *addr, int addr_len,
 			int family,
 			int type,
 			int protocol,
@@ -62,8 +61,8 @@ int nepim_create_listener_socket(struct sockaddr *addr,
 				 int win_send,
 				 int nodelay,
 				 int tos);
-int nepim_connect_client_socket(struct sockaddr *addr,
-				int addr_len,
+int nepim_connect_client_socket(const struct sockaddr *bind, int bind_len,
+				struct sockaddr *addr, int addr_len,
 				int family,
 				int type,
 				int protocol,
@@ -73,7 +72,7 @@ int nepim_connect_client_socket(struct sockaddr *addr,
 				int win_send,
 				int nodelay,
 				int tos,
-				int sock_keepalive);
+				int socket_keepalive);
 
 int nepim_sock_get_port(const struct sockaddr *addr);
 void nepim_sock_dump_addr(char *buf, int buf_size,
