@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: str.c,v 1.3 2005/11/04 09:56:15 evertonm Exp $ */
+/* $Id: str.c,v 1.4 2006/03/17 23:05:32 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <string.h>
@@ -29,7 +29,7 @@ MA 02110-1301 USA
 
 static int addr_list_sep(int c)
 {
-  return isspace(c) || (c == '/');
+  return isspace(c);
 }
 
 int addr_list_size(const char *list)
@@ -127,7 +127,7 @@ char *addr_list_append(char *list, const char *tail)
   list = realloc(list, strlen(list) + strlen(tail) + 2);
   assert(list);
   
-  strcat(list, "/");
+  strcat(list, " ");
   strcat(list, tail);
 
   return list;
