@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_client.c,v 1.67 2006/05/11 14:03:17 evertonm Exp $ */
+/* $Id: udp_client.c,v 1.68 2006/05/12 19:06:47 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -1127,7 +1127,9 @@ static void *on_udp_time_greet(oop_source *src, struct timeval tv,
   return OOP_CONTINUE;
 }
 
-static int spawn_udp_connection(const char *hostname,
+static int spawn_udp_connection(const struct sockaddr *bindaddr,
+				int bindaddr_len,
+				const char *hostname,
                                 const char *portname,
                                 struct sockaddr *remote, 
                                 socklen_t *remote_len)
@@ -1208,6 +1210,10 @@ static int spawn_udp_connection(const char *hostname,
   }
 
   for (ai = ai_res; ai; ai = ai->ai_next) {
+    char addr_str[500];
+
+    nepim_sock_dump_addr(addr_str, sizeof addr_str,
+			 ai->ai_addr, ai->ai_addrlen);
 
     if (ai->ai_family == PF_UNIX)
       fprintf(stderr, 
@@ -1215,8 +1221,8 @@ static int spawn_udp_connection(const char *hostname,
 	      hostname);
     else
       fprintf(stderr, 
-	      "UDP socket trying %s,%s\n",
-	      hostname, portname);
+	      "UDP socket trying %s,%d\n",
+	      addr_str, nepim_sock_get_port(ai->ai_addr));
 
     if (nepim_global.no_inet6 && (ai->ai_family == PF_INET6))
       continue;
@@ -1224,7 +1230,8 @@ static int spawn_udp_connection(const char *hostname,
     if (nepim_global.no_inet4 && (ai->ai_family == PF_INET))
       continue;
 
-    sd = nepim_connect_client_socket(ai->ai_addr, ai->ai_addrlen,
+    sd = nepim_connect_client_socket(bindaddr, bindaddr_len,
+				     ai->ai_addr, ai->ai_addrlen,
                                      ai->ai_family, ai->ai_socktype, 
                                      ai->ai_protocol,
                                      nepim_global.pmtu_mode,
@@ -1241,8 +1248,8 @@ static int spawn_udp_connection(const char *hostname,
 		hostname, sd);
       else
 	fprintf(stderr, 
-		"could not connect UDP socket to %s,%s: %d\n",
-		hostname, portname, sd);
+		"could not connect UDP socket to %s,%d: %d\n",
+		addr_str, nepim_sock_get_port(ai->ai_addr), sd);
       continue;
     }
 
@@ -1282,15 +1289,10 @@ static int spawn_udp_connection(const char *hostname,
 		sd, local);
       else
 	  fprintf(stderr, 
-		  "%d: UDP socket (%s,%d) connected to: "
-		  "host=%s,%s(%d) len=%d family=%d type=%d proto=%d\n",
-		  sd, 
-		  local,
+		  "%d: UDP socket (%s,%d) connected to %s,%d\n",
+		  sd, local,
 		  nepim_sock_get_port((struct sockaddr *) &local_sockaddr),
-		  hostname, portname, 
-		  nepim_sock_get_port(ai->ai_addr),
-		  ai->ai_addrlen, ai->ai_family, 
-		  ai->ai_socktype, ai->ai_protocol);
+		  addr_str, nepim_sock_get_port(ai->ai_addr));
     }
 
     break;
@@ -1306,6 +1308,21 @@ static void parse_hosts(const char *host_list)
 {
   int size = addr_list_size(host_list);
   int i, j;
+  union {
+    struct sockaddr_in inet;
+    struct sockaddr_in6 inet6;
+  } bind_buf;
+  int bind_addr_len = sizeof bind_buf;
+  struct sockaddr *bind_addr = 0;
+
+  if (nepim_global.bind_list) {
+    bind_addr = nepim_addrlist_findfirst(SOCK_DGRAM, IPPROTO_UDP,
+					 nepim_global.bind_list,
+					 (struct sockaddr *) &bind_buf,
+					 &bind_addr_len);
+    if (!bind_addr)
+      return;
+  }
 
   /* scan host_list */
   for (j = 0; j < size; ++j) {
@@ -1335,7 +1352,8 @@ static void parse_hosts(const char *host_list)
       int sd;
       nepim_greet_t opt;
 
-      sd = spawn_udp_connection(hostname, portname, 
+      sd = spawn_udp_connection(bind_addr, bind_addr_len,
+				hostname, portname, 
                                 (struct sockaddr *) &remote, 
                                 &remote_len);
       if (sd < 0)
