@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_header.c,v 1.9 2005/12/20 09:36:09 evertonm Exp $ */
+/* $Id: udp_header.c,v 1.13 2006/05/11 14:03:17 evertonm Exp $ */
 
 #include <sys/types.h>
 #include <netinet/in.h>
@@ -32,17 +32,17 @@ MA 02110-1301 USA
    local_slot  2
    remote_slot 2
    type        1
-   seq         4
+   seq         8
    seed        4
 */
-const int UDP_HEADER_LEN = 1 + 2 + 2 + 1 + 4 + 4;
+const int UDP_HEADER_LEN = 1 + 2 + 2 + 1 + 8 + 4; /* 18 */
 
 static const int UDP_HDR_OFF_VERSION  = 0;
 static const int UDP_HDR_OFF_DST_SLOT = 1;
 static const int UDP_HDR_OFF_SRC_SLOT = 3;
 static const int UDP_HDR_OFF_TYPE     = 5;
 static const int UDP_HDR_OFF_SEQ      = 6;
-static const int UDP_HDR_OFF_SEED     = 10;
+static const int UDP_HDR_OFF_SEED     = 14;
 
 int nepim_udp_hdr_parse(nepim_udp_hdr_t *hdr, const char *buf, int buf_size)
 {
@@ -53,8 +53,14 @@ int nepim_udp_hdr_parse(nepim_udp_hdr_t *hdr, const char *buf, int buf_size)
   hdr->dst_slot = nepim_uint16_read(buf + UDP_HDR_OFF_DST_SLOT);
   hdr->src_slot = nepim_uint16_read(buf + UDP_HDR_OFF_SRC_SLOT);
   hdr->type     = buf[UDP_HDR_OFF_TYPE];
-  hdr->seq      = nepim_uint32_read(buf + UDP_HDR_OFF_SEQ);
+  hdr->seq      = nepim_uint64_read(buf + UDP_HDR_OFF_SEQ);
   hdr->seed     = nepim_uint32_read(buf + UDP_HDR_OFF_SEED);
+
+#if 0
+  fprintf(stderr,
+	  "ERASEME DEBUG parse SEQ = %llu (type=%d)\n",
+	  hdr->seq, hdr->type);
+#endif
   
   return 0;
 }
@@ -62,11 +68,17 @@ int nepim_udp_hdr_parse(nepim_udp_hdr_t *hdr, const char *buf, int buf_size)
 void nepim_udp_hdr_write(const nepim_udp_hdr_t *hdr, char *buf, int buf_size)
 {
   assert(buf_size >= UDP_HEADER_LEN);
+
+#if 0
+  fprintf(stderr,
+	  "ERASEME DEBUG write SEQ = %llu\n",
+	  hdr->seq);
+#endif
   
   buf[UDP_HDR_OFF_VERSION] = hdr->version;
   nepim_uint16_write(buf + UDP_HDR_OFF_DST_SLOT, hdr->dst_slot);
   nepim_uint16_write(buf + UDP_HDR_OFF_SRC_SLOT, hdr->src_slot);
   buf[UDP_HDR_OFF_TYPE] = hdr->type;
-  nepim_uint32_write(buf + UDP_HDR_OFF_SEQ, hdr->seq);
+  nepim_uint64_write(buf + UDP_HDR_OFF_SEQ, hdr->seq);
   nepim_uint32_write(buf + UDP_HDR_OFF_SEED, hdr->seed);
 }
