@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: udp_server.c,v 1.92 2006/05/12 19:06:47 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.93 2006/05/23 20:38:41 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -989,16 +989,18 @@ static void *on_udp_segment(oop_source *src, int sd,
 					  fromlen);
 
     if (!slot) {
-      fprintf(stderr,
-	      "%d: recvfrom: unknown local slot: %d\n",
-	      sd, hdr.dst_slot);
+      if (nepim_global.debug_error_verbose)
+	fprintf(stderr,
+		"%d: recvfrom: unknown local slot: %d\n",
+		sd, hdr.dst_slot);
       return OOP_CONTINUE;
     }
 
     if (slot->index_remote != hdr.src_slot) {
-      fprintf(stderr, 
-	      "%d %d: recvfrom: remote index mismatch: expected=%d got=%d\n",
-	      sd, hdr.dst_slot, slot->index_remote, hdr.src_slot);
+      if (nepim_global.debug_error_verbose)
+	fprintf(stderr, 
+		"%d %d: recvfrom: remote index mismatch: expected=%d got=%d\n",
+		sd, hdr.dst_slot, slot->index_remote, hdr.src_slot);
       return OOP_CONTINUE;
     }
 
